@@ -47,8 +47,7 @@ test_mode(eav_t *eav, int mode, FILE *fh)
 
     rewind(fh);
     while ((read = getline (&line, &len, fh)) != EOF) {
-        line[read-1] = '\0';
-        if (read >= 2 && line[read-2] == '\r') line[read-2] = '\0';
+        remove_crlf(line, read)
 
         if (line[0] == '#') /* skip comments */
             continue;
